@@ -8,6 +8,7 @@ import asyncio
 import getpass
 import logging
 import socket
+import sys
 from pathlib import Path
 from textwrap import wrap
 
@@ -67,6 +68,13 @@ LOGGING_LEVELS = {
 pass_app_state = click.make_pass_decorator(ApplicationState, ensure=True)
 
 
+def exception_handler(exception_type, exception, traceback):  # noqa: U100
+    click.echo(f"Unexpected {exception_type.__name__}: {exception}", err=True)
+    click.echo(
+        "Use verbose mode `aiidalab-launch --verbose` to see full stack trace", err=True
+    )
+
+
 def with_profile(cmd):
     def callback(ctx, param, value):  # noqa: U100
         app_state = ctx.ensure_object(ApplicationState)
@@ -84,7 +92,10 @@ def with_profile(cmd):
     "-v",
     "--verbose",
     count=True,
-    help="Provide this option to increase the output verbosity of the launcher.",
+    help=(
+        "Increase the output verbosity of the launcher. "
+        "Use '-vv' or '-vvv' for even more verbose output"
+    ),
 )
 @pass_app_state
 def cli(app_state, verbose):
@@ -100,6 +111,10 @@ def cli(app_state, verbose):
             err=True,
         )
 
+    # Hide stack trace by default.
+    if verbose == 0:
+        sys.excepthook = exception_handler
+
     LOGGER.info(f"Configuration file path: {app_state.config_path}")
 
     latest_version = get_latest_version(timeout=0.1)
@@ -315,17 +330,15 @@ async def _async_start(
 
     # Obtain image (either via pull or local).
     if pull:
-        try:
-            msg = (
-                f"Downloading image '{instance.profile.image}', this may take a while..."
-                if instance.image is None
-                else f"Downloading latest version of '{instance.profile.image}'..."
-            )
-            with spinner(msg):
-                instance.pull()
-        except RuntimeError as error:
-            raise click.ClickException(str(error))
-    elif instance.image is None:
+        msg = (
+            f"Downloading image '{instance.profile.image}', this may take a while..."
+            if instance.image is None
+            else f"Downloading latest version of '{instance.profile.image}'..."
+        )
+        with spinner(msg):
+            instance.pull()
+
+    if instance.image is None:
         raise click.ClickException(
             f"Unable to find image '{profile.image}'. "
             "Try to use '--pull' to pull the image prior to start."
